@@ -38,9 +38,9 @@ func NewConfigGenerator(includeLegacyForwardConfig, includeLegacySyslogConfig bo
 func (engine *ConfigGenerator) Generate(forwarding *logforward.ForwardingSpec) (string, error) {
 
 	//sanitize here
-	sourceInputLabels := []string{}
-	sourceToPipelineLabels := []string{}
-	pipelineToOutputLabels := []string{}
+	var sourceInputLabels []string
+	var sourceToPipelineLabels []string
+	var pipelineToOutputLabels []string
 	var outputLabels []string
 	var err error
 
